==> struts-6.7.0-all.zip: struts-6.7.0/src/apps/showcase/src/main/java/org/apache/struts2/showcase/tag/nonui/iteratortag/IteratorGeneratorTagDemo.java <==
/*
 * $Id$
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.showcase.tag.nonui.iteratortag;

import com.opensymphony.xwork2.ActionSupport;
import org.apache.struts2.interceptor.parameter.StrutsParameter;

/**
 */
public class IteratorGeneratorTagDemo extends ActionSupport {

	private static final long serialVersionUID = 6893616642389337039L;

	private String value;
	private Integer count;
	private String separator;


	public String getValue() {
		return value;
	}

	@StrutsParameter
	public void setValue(String value) {
		this.value = value;
	}

	public Integer getCount() {
		return count;
	}

	@StrutsParameter
	public void setCount(Integer count) {
		this.count = count;
	}

	public String getSeparator() {
		return this.separator;
	}

	@StrutsParameter
	public void setSeparator(String separator) {
		this.separator = separator;
	}

	public String submit() throws Exception {
		return SUCCESS;
	}

	@Override
	public String input() throws Exception {
		return SUCCESS;
	}
}

==> struts-7.0.0-all.zip: struts-7.0.0/src/apps/showcase/src/main/java/org/apache/struts2/showcase/tag/nonui/iteratortag/IteratorGeneratorTagDemo.java <==
/*
 * $Id$
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.showcase.tag.nonui.iteratortag;

import org.apache.struts2.ActionSupport;
import org.apache.struts2.interceptor.parameter.StrutsParameter;

/**
 */
public class IteratorGeneratorTagDemo extends ActionSupport {

	private static final long serialVersionUID = 6893616642389337039L;

	private String value;
	private Integer count;
	private String separator;


	public String getValue() {
		return value;
	}

	@StrutsParameter
	public void setValue(String value) {
		this.value = value;
	}

	public Integer getCount() {
		return count;
	}

	@StrutsParameter
	public void setCount(Integer count) {
		this.count = count;
	}

	public String getSeparator() {
		return this.separator;
	}

	@StrutsParameter
	public void setSeparator(String separator) {
		this.separator = separator;
	}

	public String submit() throws Exception {
		return SUCCESS;
	}

	@Override
	public String input() throws Exception {
		return SUCCESS;
	}
}
